@@ -4,7 +4,7 @@ use 5.008_003;
 
 package SWISH::3;
 
-our $VERSION = '1.000011';
+our $VERSION = '1.000012';
 my $version = $VERSION;
 $VERSION = eval $VERSION;    # numerify
 
@@ -1094,8 +1094,8 @@ GNU General Public License for more details.
 
 =head1 SEE ALSO
 
-L<http://swish-e.org/>
+L<http://swish3.dezi.org/>, L<http://swish-e.org/>
 
-SWISH::Prog
+L<SWISH::Prog>, L<Dezi::App>
 
 =cut
